@@ -7,6 +7,7 @@ use Class::Utils qw(set_params);
 use DateTime;
 use English;
 use Error::Pure qw(err);
+use MARC::Convert::Wikidata::Utils qw(look_for_external_id);
 use Mo::utils 0.08 qw(check_isa check_required);
 use Readonly;
 use Scalar::Util qw(blessed);
@@ -25,7 +26,7 @@ Readonly::Hash our %EXT_ID_MAPPING => (
 	'lccn' => 'P243',
 );
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 # Constructor.
 sub new {
@@ -75,18 +76,6 @@ sub new {
 	return $self;
 }
 
-sub look_for_external_id {
-	my ($self, $external_id_name) = @_;
-
-	foreach my $external_id (@{$self->{'transform_object'}->external_ids}) {
-		if ($external_id->name eq $external_id_name) {
-			return $external_id->value;
-		}
-	}
-
-	return;
-}
-
 sub wikidata_authors {
 	my $self = shift;
 
@@ -105,6 +94,21 @@ sub wikidata_authors_of_introduction {
 	return $self->wikidata_people('authors_of_introduction', 'P2679');
 }
 
+sub wikidata_compilers {
+	my $self = shift;
+
+	my $property_snaks_ar = [
+		Wikibase::Datatype::Snak->new(
+			'datatype' => 'wikibase-item',
+			'datavalue' => Wikibase::Datatype::Value::Item->new(
+				'value' => 'Q29514511',
+			),
+			'property' => 'P3831',
+		),
+	];
+	return $self->wikidata_people('compilers', 'P98', $property_snaks_ar);
+}
+
 sub wikidata_descriptions {
 	my $self = shift;
 
@@ -132,6 +136,25 @@ sub wikidata_directors {
 	return $self->wikidata_people('directors', 'P57');
 }
 
+sub wikidata_dml {
+	my $self = shift;
+
+	if (! defined $self->{'transform_object'}->dml) {
+		return;
+	}
+
+	return Wikibase::Datatype::Statement->new(
+		'references' => [$self->wikidata_reference],
+		'snak' => Wikibase::Datatype::Snak->new(
+			'datatype' => 'external-id',
+			'datavalue' => Wikibase::Datatype::Value::String->new(
+				'value' => $self->{'transform_object'}->dml,
+			),
+			'property' => 'P11378',
+		),
+	);
+}
+
 sub wikidata_edition_number {
 	my $self = shift;
 
@@ -203,40 +226,6 @@ sub wikidata_external_ids {
 	return @ret;
 }
 
-sub wikidata_compilers {
-	my $self = shift;
-
-	my $property_snaks_ar = [
-		Wikibase::Datatype::Snak->new(
-			'datatype' => 'wikibase-item',
-			'datavalue' => Wikibase::Datatype::Value::Item->new(
-				'value' => 'Q29514511',
-			),
-			'property' => 'P3831',
-		),
-	];
-	return $self->wikidata_people('compilers', 'P98', $property_snaks_ar);
-}
-
-sub wikidata_dml {
-	my $self = shift;
-
-	if (! defined $self->{'transform_object'}->dml) {
-		return;
-	}
-
-	return Wikibase::Datatype::Statement->new(
-		'references' => [$self->wikidata_reference],
-		'snak' => Wikibase::Datatype::Snak->new(
-			'datatype' => 'external-id',
-			'datavalue' => Wikibase::Datatype::Value::String->new(
-				'value' => $self->{'transform_object'}->dml,
-			),
-			'property' => 'P11378',
-		),
-	);
-}
-
 sub wikidata_illustrators {
 	my $self = shift;
 
@@ -658,7 +647,7 @@ sub wikidata_publishers {
 sub wikidata_reference {
 	my $self = shift;
 
-	my $ccnb = $self->look_for_external_id('cnb');
+	my $ccnb = look_for_external_id($self->{'transform_object'}, 'cnb');
 	if (! defined $ccnb) {
 		err decode_utf8('Missing ČČNB id.');
 	}
