@@ -37,7 +37,7 @@ Readonly::Hash our %PEOPLE_TYPE => {
 	'trl' => 'translators',
 };
 
-our $VERSION = 0.12;
+our $VERSION = 0.13;
 
 # Constructor.
 sub new {
@@ -268,6 +268,22 @@ sub _languages {
 	return @lang;
 }
 
+sub _lccn {
+	my $self = shift;
+
+	my @ret;
+
+	my @lccn = $self->_subfield('035', 'a');
+	foreach my $lccn (@lccn) {
+		$lccn = clean_oclc($lccn);
+		push @ret, MARC::Convert::Wikidata::Object::ExternalId->new(
+			'name' => 'lccn',
+			'value' => $lccn,
+		);
+	}
+
+	return @ret;
+}
 
 sub _number_of_pages {
 	my $self = shift;
@@ -278,23 +294,6 @@ sub _number_of_pages {
 	return $number_of_pages;
 }
 
-sub _oclc {
-	my $self = shift;
-
-	my @ret;
-
-	my @oclc = $self->_subfield('035', 'a');
-	foreach my $oclc (@oclc) {
-		$oclc = clean_oclc($oclc);
-		push @ret, MARC::Convert::Wikidata::Object::ExternalId->new(
-			'name' => 'lccn',
-			'value' => $oclc,
-		);
-	}
-
-	return @ret;
-}
-
 sub _process_object {
 	my $self = shift;
 
@@ -322,7 +321,7 @@ sub _process_object {
 		'end_time' => $end_time,
 		'external_ids' => [
 			$self->_ccnb,
-			$self->_oclc,
+			$self->_lccn,
 		],
 		'isbns' => [$self->_isbns],
 		'issn' => $self->_issn,
@@ -385,10 +384,15 @@ sub _process_people {
 			MARC::Convert::Wikidata::Object::People->new(
 				'date_of_birth' => $date_of_birth,
 				'date_of_death' => $date_of_death,
+				'external_ids' => [
+					MARC::Convert::Wikidata::Object::ExternalId->new(
+						'name' => 'nkcr_aut',
+						'value' => $nkcr_aut,
+					),
+				],
 				'work_period_start' => $work_period_start,
 				'work_period_end' => $work_period_end,
 				'name' => $name,
-				'nkcr_aut' => $nkcr_aut,
 				'surname' => $surname,
 			);
 	}
